@@ -47,14 +47,16 @@ class ScriptManager:
              "orca.scripts.apps",
              "orca.scripts.toolkits"]
         self._appNames = \
-            {'Firefox':          'Mozilla',
-             'Icedove':          'Thunderbird',
-             'empathy-chat':     'empathy',
+            {'Firefox': 'Mozilla',
+             'Icedove': 'Thunderbird',
+             'Nereid': 'Banshee',
+             'empathy-chat': 'empathy',
              'gnome-calculator': 'gcalctool',
-             'marco':            'metacity',
-             'Nereid':           'Banshee',
+             'gtk-window-decorator': 'switcher',
+             'marco': 'switcher',
              'mate-notification-daemon': 'notification-daemon',
-             'pluma':            'gedit',
+             'metacity': 'switcher',
+             'pluma': 'gedit',
             }
 
         self.setActiveScript(None, "__init__")
@@ -99,10 +101,12 @@ class ScriptManager:
         if not appAndNameExist:
             return None
 
-        # Many python apps have an accessible name which ends in '.py'.
-        # Sometimes OOo has 'soffice.bin' as its name.
-        name = app.name.split('.')[0]
+        name = app.name
         altNames = list(self._appNames.keys())
+        if name.endswith(".py") or name.endswith(".bin"):
+            name = name.split('.')[0]
+        elif name.startswith("org.") or name.startswith("com."):
+            name = name.split('.')[-1]
 
         names = [n for n in altNames if n.lower() == name.lower()]
         if names:
@@ -338,15 +342,25 @@ class ScriptManager:
             try:
                 return app.get_process_id()
             except:
+                msg = "SCRIPT MANAGER: Exception getting pid for %s" % app
+                debug.println(debug.LEVEL_INFO, msg, True)
                 return -1
 
+        def _isValidApp(app):
+            try:
+                return a in self._desktop
+            except:
+                msg = "SCRIPT MANAGER: Exception seeing if %s is in desktop" % app
+                debug.println(debug.LEVEL_INFO, msg, True)
+                return False
+
         pid = _pid(app)
         if pid == -1:
             return None
 
         items = self.appScripts.items()
         for a, script in items:
-            if a != app and _pid(a) == pid and a in self._desktop:
+            if a != app and _pid(a) == pid and _isValidApp(a):
                 return script
 
         return None
